pub struct CanonicalResultDivergence {
pub path: String,
pub expected: Option<Value>,
pub actual: Option<Value>,
}Expand description
The first difference between two canonical backtest results.
Fields
path: StringRFC 6901 JSON Pointer to the differing field or record.
expected: Option<Value>The expected value, or None when the field or record is absent.
actual: Option<Value>The actual value, or None when the field or record is absent.